#!/bin/sh

# Name: linux-live
# Summary: Da famous scripts from Tomas M, for creating a Live CD .
# Homepage: http://www.linux-live.org/
# Maintainer: Pierric Le Brun <akuna@free.fr>

PKGNAME='linux-live'
PKGVER='6.2.9'
PKGBUILD='60.4'
ARCH='noarch'

LIVECDNAME=zenlive
BUILDIR=`pwd`
SRCTAR=$BUILDIR/$PKGNAME-$PKGVER.tar.gz
SRCDIR=$BUILDIR/$PKGNAME-$PKGVER
PKGDIR=$BUILDIR/$PKGNAME-$PKGVER-$ARCH-$PKGBUILD

# Extract and prepare sources
rm -rf $PKGNAME-$PKGVER
tar -pxf $SRCTAR

# Apply runlevel patch
cd $SRCDIR/initrd
patch -p0 < $BUILDIR/linuxrc-runlevel.patch

# Copy tools to target directory
rm -rf $PKGDIR

mkdir -p $PKGDIR/usr/bin
cp $SRCDIR/tools/* $PKGDIR/usr/bin
rm -rf $PKGDIR/usr/bin/liblinuxlive

mkdir -p $PKGDIR/usr/lib
cat $SRCDIR/tools/liblinuxlive | sed -r 's/^LIVECDNAME=.*/LIVECDNAME="'$LIVECDNAME'"/' > $PKGDIR/usr/lib/liblinuxlive

mkdir -p $PKGDIR/usr/share/zenlive/liveskel/zenlive
cp $SRCDIR/cd-root/linux/livecd.sgn $PKGDIR/usr/share/zenlive/liveskel/zenlive
cat $SRCDIR/cd-root/linux/make_iso.sh | sed -r 's/^CDLABEL=.*/CDLABEL="'$LIVECDNAME'"/' > $PKGDIR/usr/share/zenlive/liveskel/zenlive/make_iso.sh
chmod +x $PKGDIR/usr/share/zenlive/liveskel/zenlive/make_iso.sh

mkdir -p $PKGDIR/usr/share/zenlive/linux-live/initrd
cp README build $SRCDIR/ $PKGDIR/usr/share/zenlive/linux-live
cat $SRCDIR/.config | sed -r 's/^LIVECDNAME=.*/LIVECDNAME="'$LIVECDNAME'"/' > $PKGDIR/usr/share/zenlive/linux-live/.config
cp -Rf $SRCDIR/initrd/* $PKGDIR/usr/share/zenlive/linux-live/initrd
cd $PKGDIR/usr/share/zenlive/linux-live/initrd
rm -rf liblinuxlive
ln -sf ../../../../lib/liblinuxlive liblinuxlive 

# Copy docs
mkdir -p $PKGDIR/usr/doc/$PKGNAME-$PKGVER
cd $SRCDIR/DOC
cp *txt LICENSE GNU* $PKGDIR/usr/doc/$PKGNAME-$PKGVER 
cd $SRCDIR
cp TODO $PKGDIR/usr/doc/$PKGNAME-$PKGVER 
chmod 644 $PKGDIR/usr/doc/$PKGNAME-$PKGVER/*

# Write out slack-desc
mkdir -p $PKGDIR/install
cat > $PKGDIR/install/slack-desc << EOF
$PKGNAME: Linux Live Scripts
$PKGNAME: 
$PKGNAME: Tools for creating a LiveCD
$PKGNAME:
$PKGNAME: Linux Live is a set of shell scripts which allows you to create your
$PKGNAME: own Live Linux from an already installed Linux distribution.
$PKGNAME: The Live system you create will be bootable from a CD-ROM or a disk 
$PKGNAME: device, for example a USB Flash Drive, a USB Pen Drive, a Camera 
$PKGNAME: connected to USB port, and so on.
$PKGNAME:
$PKGNAME:
EOF

# Copy this build script into the package
mkdir -p $PKGDIR/usr/src/$PKGNAME-$PKGVER
cp $BUILDIR/build-$PKGNAME.sh $PKGDIR/usr/src/$PKGNAME-$PKGVER/

# Create the package
cd $PKGDIR
makepkg -l y -c n $BUILDIR/$PKGNAME-$PKGVER-$ARCH-$PKGBUILD.tgz

cd $BUILDIR
md5sum $PKGNAME-$PKGVER-$ARCH-$PKGBUILD.tgz > $PKGNAME-$PKGVER-$ARCH-$PKGBUILD.md5
echo "ash,aufs2-util,kernelive" > $BUILDIR/$PKGNAME-$PKGVER-$ARCH-$PKGBUILD.dep
